/*********************************************************************
 Copyright (C) 2003 Imperial College London

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
***********************************************************************/

package vishnu.server.Search;

import java.util.Vector;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.File;

import org.greenstone.mg.*;

public class MGSearcher implements SearchInterface
{
 
    private String collection_home;
    private String collection_name;
    private Vector docIDs;
    private Vector docDescs;
    private String mg_index_path;
    private MGWrapper mg_src;
    
    public MGSearcher(String coll_home, String coll_name, String view)
    {
	collection_home = coll_home;
	if (!collection_home.endsWith(File.separator)) {
	    collection_home += File.separator;
	}
	collection_name = coll_name;
	mg_src = new MGWrapper();
	mg_index_path = "index"+File.separator+"mg_index"+ File.separator;
	if (view != null) {
	    mg_index_path += view + File.separator;
	}
	mg_index_path += collection_name+File.separator+collection_name;
	mg_src.setIndex(mg_index_path);
    }


    public Vector getDocIdentifiers()
    {
	return docIDs;
    }


    public Vector getDocDescriptions()
    {
	return docDescs;
    }	

    // why do we want document in a vector ?? -- kjdon
    public Vector getDocContent(int doc_num) {

	Vector document = new Vector();
	String doc_content = this.mg_src.getDocument(collection_home, mg_index_path, doc_num);
	String [] lines = doc_content.split("\n");
	for (int i=0; i<lines.length; i++) {
	    document.addElement(lines[i]);
	}
	return document;

    }

    public void search(String query) {
	this.mg_src.runQuery(collection_home, mg_index_path, query);
	MGQueryResult mqr = this.mg_src.getQueryResult();
	docIDs = new Vector();
	docDescs = new Vector();
	Vector doc_results =   mqr.getDocs();
	int max_docs = Math.min(MAX_DOCS,doc_results.size());
	for (int i=0; i<max_docs; i++) {
	    int doc_num = (int)((MGDocInfo)doc_results.get(i)).num_;
	    docIDs.addElement(new Integer(doc_num));
	    String doc_content = this.mg_src.getDocument(collection_home, mg_index_path, doc_num);
	    docDescs.addElement(doc_content.substring(0,MAX_DESCRIPTION_LENGTH));
	}	
    }
    
}







